const path = require("path");
const log4js = require("log4js");
const logger = log4js.getLogger("MainProcess");
const {
    app,
    globalShortcut,
    dialog,
    BrowserWindow
} = require("electron");

let isInstalling = false;
let mainWindow;

function main() {
    logger.debug("main", process.argv);
    try {
        isInstalling = (require("electron-squirrel-startup"));
    } catch (err) {
        logger.debug("isInstalling = false");
    }

    if (isInstalling) {
        //only on ms-windows production app
        dialog.showMessageBox(null, {
            type: "none",
            buttons: ["OK"],
            title: "Installation Completed",
            message: "appilcation shortcut icon has been added to desktop and start menu."
        });

    } else {
        createWindow();
    }
}

function createWindow() {

    let windowOption = {
        width: 955,
        height: 620,
        resizable: false,
        title: "TTOA",
        backgroundColor: "#333333",
        show: false,
        webPreferences: {
            plugins: true,
            webSecurity: false
        }
    };
    if (process.platform=="win32") {
        windowOption.width += 20;
        windowOption.height += 20;
    }
    mainWindow = new BrowserWindow(windowOption);
    mainWindow.on("close", () => {
        mainWindow = null;
    });
    mainWindow.on("focus", () => {
        mainWindow.flashFrame(false);
        globalShortcut.register("Command+W", hideMainWidnow);
        globalShortcut.register("Command+M", minimizeMainWindow);
        globalShortcut.register("CommandOrControl+Alt+J", openDevTools);
    });
    mainWindow.on("blur", () => {
        globalShortcut.unregister("Command+W", hideMainWidnow);
        globalShortcut.unregister("Command+M", minimizeMainWindow);
        globalShortcut.unregister("CommandOrControl+Alt+J", openDevTools);
    });
    mainWindow.on("ready-to-show", function() {
        mainWindow.show();
        mainWindow.focus();
    });
    globalShortcut.register("Command+W", hideMainWidnow);
    globalShortcut.register("Command+M", minimizeMainWindow);
    globalShortcut.register("CommandOrControl+Alt+J", openDevTools);



    let url;
    if (process.env.NODE_ENV == "development") {
        url = path.join("file://", __dirname,  "../", "bin", "index.html");
    } else {
        url = path.join("file://", __dirname,  "bin", "index.html");
    }
    mainWindow.loadURL(url);
}




function hideMainWidnow() {
    if (mainWindow) {
        mainWindow.hide();
    }
}

function minimizeMainWindow() {
    if (mainWindow) {
        mainWindow.minimize();
    }
}

function openDevTools() {
    if (process.env.NODE_ENV == "development") {
        if (mainWindow) {
            mainWindow.webContents.openDevTools({mode: "undocked"});
        }
    }
}



function activateMainWindow() {
    if (mainWindow) {
        mainWindow.show();
        if (mainWindow.isMinimized()) {
            mainWindow.restore();
        }
        mainWindow.focus();
    }
}

const hasOldInstance = app.makeSingleInstance(() => {
    activateMainWindow();
});
if (hasOldInstance) {
    app.quit();
}

let pluginName;
switch (process.platform) {
    case "win32":
        pluginName = "pepflashplayer.dll";
        break;
    case "darwin":
        pluginName = "PepperFlashPlayer.plugin";
        break;
}
app.commandLine.appendSwitch("ppapi-flash-path", path.join(__dirname, "plugins", pluginName));
app.on("window-all-closed", () => {
    app.quit();
});
app.on("ready", main);
